==> alg-common-1.17.3-20190619.070102-1-sources.jar: cn/com/duiba/nezha/alg/common/model/activityselectconversionforms/SameCostActivitiesInfo.java <==
package cn.com.duiba.nezha.alg.common.model.activityselectconversionforms;

/**
 * Created by Administrator on 2018/12/24.
 */
public class SameCostActivitiesInfo {
    Long activityId;
    int sameActivityCnt;
    Long activityType;
    int ifSelected;
    int index;
    double mabReward;
    double changeScore;
    double diffChangeScore;
    boolean isHot;
    //3.5版本新增参数
    int ifOldActivity; //是否老活动，1：是；0：不是



    public int getIfOldActivity() {
        return ifOldActivity;
    }

    public void setIfOldActivity(int ifOldActivity) {
        this.ifOldActivity = ifOldActivity;
    }



    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public int getSameActivityCnt() {
        return sameActivityCnt;
    }

    public void setSameActivityCnt(int sameActivityCnt) {
        this.sameActivityCnt = sameActivityCnt;
    }

    public Long getActivityType() {
        return activityType;
    }

    public void setActivityType(Long activityType) {
        this.activityType = activityType;
    }

    public int getIfSelected() {
        return ifSelected;
    }

    public void setIfSelected(int ifSelected) {
        this.ifSelected = ifSelected;
    }

    public int getIndex() {
        return index;
    }

    public void setIndex(int index) {
        this.index = index;
    }

    public double getMabReward() {
        return mabReward;
    }

    public void setMabReward(double mabReward) {
        this.mabReward = mabReward;
    }

    public double getChangeScore() {
        return changeScore;
    }

    public void setChangeScore(double changeScore) {
        this.changeScore = changeScore;
    }

    public double getDiffChangeScore() {
        return diffChangeScore;
    }

    public void setDiffChangeScore(double diffChangeScore) {
        this.diffChangeScore = diffChangeScore;
    }

    public boolean isHot() {
        return isHot;
    }

    public void setHot(boolean hot) {
        isHot = hot;
    }

    @Override
    public String toString() {
        return "SameCostActivitiesInfo{" +
                "activityId=" + activityId +
                ", sameActivityCnt=" + sameActivityCnt +
                ", activityType=" + activityType +
                ", ifSelected=" + ifSelected +
                ", index=" + index +
                ", mabReward=" + mabReward +
                ", changeScore=" + changeScore +
                ", diffChangeScore=" + diffChangeScore +
                ", isHot=" + isHot +
                ", ifOldActivity=" + ifOldActivity +
                '}';
    }
}

==> alg-common-1.19.6-20190827.093751-3-sources.jar: cn/com/duiba/nezha/alg/common/model/activityselectconversionforms/SameCostActivitiesInfo.java <==
package cn.com.duiba.nezha.alg.common.model.activityselectconversionforms;

/**
 * Created by Administrator on 2018/12/24.
 */
public class SameCostActivitiesInfo {
    Long activityId;
    int sameActivityCnt;
    Long activityType;
    int ifSelected;
    int index;
    double mabReward;
    double changeScore;
    double diffChangeScore;
    double diffReward;
    boolean isHot;
    //3.5版本新增参数
    int ifOldActivity; //是否老活动，1：是；0：不是
    double hrpm;
    double arpm;
    double grpm;



    public int getIfOldActivity() {
        return ifOldActivity;
    }

    public void setIfOldActivity(int ifOldActivity) {
        this.ifOldActivity = ifOldActivity;
    }



    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public int getSameActivityCnt() {
        return sameActivityCnt;
    }

    public void setSameActivityCnt(int sameActivityCnt) {
        this.sameActivityCnt = sameActivityCnt;
    }

    public Long getActivityType() {
        return activityType;
    }

    public void setActivityType(Long activityType) {
        this.activityType = activityType;
    }

    public int getIfSelected() {
        return ifSelected;
    }

    public void setIfSelected(int ifSelected) {
        this.ifSelected = ifSelected;
    }

    public int getIndex() {
        return index;
    }

    public void setIndex(int index) {
        this.index = index;
    }

    public double getMabReward() {
        return mabReward;
    }

    public void setMabReward(double mabReward) {
        this.mabReward = mabReward;
    }

    public double getChangeScore() {
        return changeScore;
    }

    public void setChangeScore(double changeScore) {
        this.changeScore = changeScore;
    }

    public double getDiffChangeScore() {
        return diffChangeScore;
    }

    public void setDiffChangeScore(double diffChangeScore) {
        this.diffChangeScore = diffChangeScore;
    }

    public boolean isHot() {
        return isHot;
    }

    public void setHot(boolean hot) {
        isHot = hot;
    }

    public double getDiffReward() {
        return diffReward;
    }

    public void setDiffReward(double diffReward) {
        this.diffReward = diffReward;
    }

    public double getHrpm() {
        return hrpm;
    }

    public void setHrpm(double hrpm) {
        this.hrpm = hrpm;
    }

    public double getArpm() {
        return arpm;
    }

    public void setArpm(double arpm) {
        this.arpm = arpm;
    }

    public double getGrpm() {
        return grpm;
    }

    public void setGrpm(double grpm) {
        this.grpm = grpm;
    }

    @Override
    public String toString() {
        return "SameCostActivitiesInfo{" +
                "activityId=" + activityId +
                ", sameActivityCnt=" + sameActivityCnt +
                ", activityType=" + activityType +
                ", ifSelected=" + ifSelected +
                ", index=" + index +
                ", mabReward=" + mabReward +
                ", changeScore=" + changeScore +
                ", diffChangeScore=" + diffChangeScore +
                ", diffReward=" + diffReward +
                ", isHot=" + isHot +
                ", ifOldActivity=" + ifOldActivity +
                ", hrpm=" + hrpm +
                ", arpm=" + arpm +
                ", grpm=" + grpm +
                '}';
    }
}
